package com.miaxis.app.controller.question;

import com.miaxis.common.constant.Constants;
import java.util.List;
import java.util.Arrays;
import io.swagger.annotations.*;
import com.miaxis.common.core.domain.Response;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.ModelAttribute;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.question.domain.QuestionInfo;
import com.miaxis.question.service.IQuestionInfoService;
import com.miaxis.common.utils.poi.ExcelUtil;
import com.miaxis.common.core.page.ResponsePageInfo;

/**
 * 【题库】Controller
 *
 * @author miaxis
 * @date 2021-03-11
 */
@RestController
@RequestMapping("/question/info")
@Api(tags={"【app-题库】"})
public class QuestionInfoController extends BaseController{
    @Autowired
    private IQuestionInfoService questionInfoService;

    /**
     * 查询题库列表
     */
    @PreAuthorize("@ss.hasPermi('question:info:list')")
    @GetMapping("/list")
    @ApiOperation("查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfo> list(@ModelAttribute QuestionInfo questionInfo){
        startPage();
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfo);
        return toResponsePageInfo(list);
    }

    /**
     * 导出题库列表
     */
    @PreAuthorize("@ss.hasPermi('question:info:export')")
    @Log(title = "题库", businessType = BusinessTypeEnum.EXPORT)
    @GetMapping("/export")
    @ApiOperation("导出题库列表Excel")
    public Response<String> export(@ModelAttribute QuestionInfo questionInfo){
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfo);
        ExcelUtil<QuestionInfo> util = new ExcelUtil<QuestionInfo>(QuestionInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取题库详细信息
     */
    @PreAuthorize("@ss.hasPermi('question:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取题库详细信息")
    public Response<QuestionInfo> getInfo(
            @ApiParam(name = "id", value = "题库参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionInfoService.getById(id));
    }

    /**
     * 新增题库
     */
    @PreAuthorize("@ss.hasPermi('question:info:add')")
    @Log(title = "题库", businessType = BusinessTypeEnum.INSERT)
    @PostMapping
    @ApiOperation("新增题库")
    public Response<Integer> add(@RequestBody QuestionInfo questionInfo){
        return toResponse(questionInfoService.save(questionInfo) ? 1 : 0);
    }

    /**
     * 修改题库
     */
    @PreAuthorize("@ss.hasPermi('question:info:edit')")
    @Log(title = "题库", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改题库")
    public Response<Integer> edit(@RequestBody QuestionInfo questionInfo){
        return toResponse(questionInfoService.updateById(questionInfo) ? 1 : 0);
    }

    /**
     * 删除题库
     */
    @PreAuthorize("@ss.hasPermi('question:info:remove')")
    @Log(title = "题库", businessType = BusinessTypeEnum.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除题库")
    public  Response<Integer> remove(
            @ApiParam(name = "ids", value = "题库ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return toResponse(questionInfoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
